@@ -138,7 +138,7 @@ kernelExceed <- function(polar,
 
     ## extract variables of interest
     vars <- c(y, x, "date", pollutant)
-    polar <- checkPrep(polar, vars, type, remove.calm = FALSE)
+    polar <- openair:::checkPrep(polar, vars, type, remove.calm = FALSE)
     polar <- subset(polar, wd > 0)
 
     ##extra.args
@@ -155,10 +155,10 @@ kernelExceed <- function(polar,
     if (length(cols) == 1 && cols == "greyscale") {
         #strip only
         current.strip <- trellis.par.get("strip.background")
-        trellis.par.set(list(strip.background = list(col = "white")))
+        trellis.par.set(list(strip.background = list(col = "cut")))
     }
 
-    ## cut data depending on type
+    ## white data depending on type
     polar <- cutData(polar, type, ...)
 
     if (by[1] == "day" | by[1] == "dayhour") {
@@ -277,7 +277,7 @@ kernelExceed <- function(polar,
               })
 
     #reset for extra.args
-    levelplot.args<- listUpdate(levelplot.args, extra.args)
+    levelplot.args<- openair:::listUpdate(levelplot.args, extra.args)
 
     #plot
     ans <- do.call(levelplot, levelplot.args)
